@@ -15,20 +15,27 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 
 namespace crl {
 
-using time_type = std::int64_t;
+using time = std::int64_t;
+using profile_time = std::int64_t;
 
 namespace details {
 
 using inner_time_type = std::int64_t;
+using inner_profile_type = std::int64_t;
 
 void init();
+
 inner_time_type current_value();
-time_type convert(inner_time_type value);
+time convert(inner_time_type value);
+
+inner_profile_type current_profile_value();
+profile_time convert_profile(inner_profile_type);
 
 } // namespace details
 
 // Thread-safe.
-time_type time();
+time now();
+profile_time profile();
 
 // Returns true if some adjustment was made.
 bool adjust_time();
