@@ -11,8 +11,8 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 
 #ifdef CRL_USE_WINAPI
 
-#include <windows.h>
 #include <exception>
+#include <crl/winapi/crl_winapi_windows_h.h>
 
 namespace crl::details {
 
